"use strict";
/*
Copyright 2024 New Vector Ltd.
Copyright 2017 OpenMarket Ltd

SPDX-License-Identifier: AGPL-3.0-only OR GPL-3.0-only
Please see LICENSE files in the repository root for full details.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSquirrelExecutable = getSquirrelExecutable;
const path_1 = __importDefault(require("path"));
const child_process_1 = require("child_process");
const electron_1 = require("electron");
function getSquirrelExecutable() {
    return path_1.default.resolve(path_1.default.dirname(process.execPath), "..", "Update.exe");
}
function runUpdateExe(args) {
    // Invokes Squirrel's Update.exe which will do things for us like create shortcuts
    // Note that there's an Update.exe in the app-x.x.x directory and one in the parent
    // directory: we need to run the one in the parent directory, because it discovers
    // information about the app by inspecting the directory it's run from.
    const updateExe = getSquirrelExecutable();
    console.log(`Spawning '${updateExe}' with args '${args}'`);
    return new Promise((resolve) => {
        (0, child_process_1.spawn)(updateExe, args, {
            detached: true,
        }).on("close", resolve);
    });
}
function checkSquirrelHooks() {
    if (process.platform !== "win32")
        return false;
    const cmd = process.argv[1];
    const target = path_1.default.basename(process.execPath);
    switch (cmd) {
        case "--squirrel-install":
            void runUpdateExe(["--createShortcut=" + target]).then(() => electron_1.app.quit());
            return true;
        case "--squirrel-updated":
        case "--squirrel-obsolete":
            electron_1.app.quit();
            return true;
        case "--squirrel-uninstall":
            void runUpdateExe(["--removeShortcut=" + target]).then(() => electron_1.app.quit());
            return true;
        default:
            return false;
    }
}
if (checkSquirrelHooks()) {
    process.exit(1);
}
